ScreenPy Adapter: Allure
========================

```
TITLE CARD:
                         "ScreenPy Adapter: Allure"
TITLE DISAPPEARS.
                                                                      FADE IN:
INT. DOCUMENTATION - UNKNOWN TIME

A recording room door opens and AUDIENCE peeks inside. AUDIENCE quietly steps
over cords and around chairs, approaching the switchboard. NARRATOR quietly
resumes their guidance.

                              NARRATOR (V.O.)
            Ah, this is one of the Adapters for my microphone. This
            one sends them to an Allure report.

                              AUDIENCE
                              (hushed)
            You mean you have a literal microphone, and that's how
            you're talking to me? I thought I had been stingy to
            some tester and you were the first of three spirits.

                              NARRATOR (V.O.)
            Not a literal microphone, but it's a helpful metaphor.

                              AUDIENCE
                              (hushed)
            That's not as helpful as you think it is, when your
            voice is in my head.

A beat, as AUDIENCE looks appraisingly at the equipment.

                              AUDIENCE (CONT'D)
                              (hushed)
            This looks complicated. I'm leaving now.

                              NARRATOR (V.O.)
            Let's turn left outside the door...

                                                                      FADE OUT
```


Installation
------------
    pip install screenpy_adapter_allure

or

    pip install screenpy[allure]


Documentation
----------
Please check out the [Read The Docs documentation](https://screenpy-adapter-allure-docs.readthedocs.io/en/latest/) for the latest information about this module!

You can also read the [ScreenPy Docs](https://screenpy-docs.readthedocs.io/en/latest/) for more information about ScreenPy in general.


Contributing
------------
You want to contribute? Great! Here are the things you should do before submitting your PR:

1. Install [`pre-commit`](https://pre-commit.com/)
1. run `pre-commit install` once.
1. run `tox` to perform tests frequently.

That's it! :)
